@@ -5,7 +5,7 @@
 ;; Author: Matthew Carter <m@ahungry.com>
 ;; Maintainer: Matthew Carter <m@ahungry.com>
 ;; URL: https://github.com/ahungry/color-theme-ahungry
-;; Version: 1.6.0
+;; Version: 1.7.0
 ;; Keywords: ahungry palette color theme emacs color-theme deftheme
 ;; Package-Requires: ((emacs "24"))
 
@@ -36,6 +36,9 @@
 
 ;;; News:
 
+;;;; Changes since 1.6.0:
+;; - Add man/woman faces.
+
 ;;;; Changes since 1.5.0:
 ;; - Bump up font size
 ;; - Make dark blues a little brighter.
@@ -290,6 +293,8 @@ Default value:
    '(button ((t (:foreground "#0055ff" :bold t :underline t))))
    '(Man-overstrike ((t (:foreground "yellow" :bold t))))
    '(Man-underline ((t (:foreground "orange" :underline t))))
+   '(woman-bold ((t (:foreground "yellow" :bold t))))
+   '(woman-italic ((t (:foreground "orange" :underline t))))
    )
   (custom-theme-set-variables
    'ahungry
